@@ -112,7 +112,11 @@ invoke_perl_code (ffi_cif* cif, gpointer resp, gpointer* args, gpointer userdata
 				? *((gpointer *) args[i+args_offset])
 				: args[i+args_offset];
 			raw_to_arg (raw, &arg, arg_type);
-			sv = SAVED_STACK_SV (arg_to_sv (&arg, arg_type, transfer, &iinfo.base));
+			sv = SAVED_STACK_SV (arg_to_sv (&arg,
+			                                arg_type,
+			                                transfer,
+			                                GPERL_I11N_MEMORY_SCOPE_IRRELEVANT,
+			                                &iinfo.base));
 			/* If arg_to_sv returns NULL, we take that as 'skip
 			 * this argument'; happens for GDestroyNotify, for
 			 * example. */
@@ -358,8 +362,10 @@ _prepare_perl_invocation_info (GPerlI11nPerlInvocationInfo *iinfo,
 		if (arg_tag == GI_TYPE_TAG_ARRAY) {
 			gint pos = g_type_info_get_array_length (arg_type);
 			if (pos >= 0) {
-				GITypeInfo *length_arg_type = &(iinfo->base.arg_types[pos]);
-				raw_to_arg (args[pos], &iinfo->base.aux_args[pos], length_arg_type);
+				GITypeInfo *length_arg_type;
+				guint args_pos = iinfo->base.is_signal ? pos+1 : pos;
+				length_arg_type = &(iinfo->base.arg_types[pos]);
+				raw_to_arg (args[args_pos], &iinfo->base.aux_args[pos], length_arg_type);
 				dwarn ("  pos %d is array length => %"G_GSIZE_FORMAT"\n",
 				       pos, iinfo->base.aux_args[pos].v_size);
 			}
